Struct fred::mocks::SimpleMap

source ·
pub struct SimpleMap { /* private fields */ }
Available on crate feature mocks only.
A struct that implements some of the basic mapping functions. If callers require a mocking layer that stores and operates on real values then this struct is a good place to start.

Note: This does not support expirations or NX|XX qualifiers.

#[tokio::test]
async fn should_use_echo_mock() {
  let config = RedisConfig {
    mocks: Some(Arc::new(SimpleMap::new())),
    ..Default::default()
  };
  let client = Builder::from_config(config).build().unwrap();
  client.init().await.expect("Failed to connect");

  let actual: String = client
      .set("foo", "bar", None, None, false)
      .await
      .expect("Failed to call SET");
  assert_eq!(actual, "OK");

  let actual: String = client.get("foo").await.expect("Failed to call GET");
  assert_eq!(actual, "bar");
}

Implementations

source

impl SimpleMap

source

pub fn new() -> Self

Create a new empty SimpleMap.

source

pub fn clear(&self)

Clear the inner map.

source

pub fn take(&self) -> HashMap<RedisKey, RedisValue>

Take the inner map.

source

pub fn inner(&self) -> HashMap<RedisKey, RedisValue>

Read a copy of the inner map.

source

pub fn get(&self, args: Vec<RedisValue>) -> Result<RedisValue, RedisError>

Perform a GET operation.

source

pub fn set(&self, args: Vec<RedisValue>) -> Result<RedisValue, RedisError>

Perform a SET operation.

source

pub fn del(&self, args: Vec<RedisValue>) -> Result<RedisValue, RedisError>

Perform a DEL operation.